// Copyright (c) 2004 David Muse
// See the COPYING file for more information

#include <rudiments/private/inttypes.h>
